@@ -7,6 +7,7 @@
 
 #include <QApplication>
 #include <QGuiApplication>
+#include <QIcon>
 #include <QQmlApplicationEngine>
 #include <QUrl>
 #include <QAudioRecorder>
@@ -50,7 +51,6 @@ Q_DECL_EXPORT int main(int argc, char *argv[])
                          QStringLiteral("Audio recorder"),
                          KAboutLicense::GPL,
                          i18n("© 2020-2022 KDE Community"));
-    aboutData.setBugAddress("https://invent.kde.org/plasma-mobile/krecorder/-/issues");
     aboutData.addAuthor(i18n("Devin Lin"), QString(), QStringLiteral("devin@kde.org"));
     aboutData.addAuthor(i18n("Jonah Brüchert"), QString(), QStringLiteral("jbb@kaidan.im"));
     KAboutData::setApplicationData(aboutData);
@@ -58,10 +58,9 @@ Q_DECL_EXPORT int main(int argc, char *argv[])
     QCommandLineParser parser;
     parser.addVersionOption();
     parser.process(app);
-    
-    if (qEnvironmentVariableIsEmpty("QT_QUICK_CONTROLS_STYLE")) {
-        QQuickStyle::setStyle(QStringLiteral("org.kde.desktop"));
-    }
+
+    // pre-initialize settings model to apply settings to the AudioRecorder instance
+    SettingsModel::instance();
 
     qmlRegisterType<Recording>("KRecorder", 1, 0, "Recording");
     qmlRegisterType<AudioProber>("KRecorder", 1, 0, "AudioProber");
@@ -92,5 +91,8 @@ Q_DECL_EXPORT int main(int argc, char *argv[])
         return -1;
     }
 
+    // required for X11
+    app.setWindowIcon(QIcon::fromTheme(QStringLiteral("org.kde.krecorder")));
+
     return app.exec();
 }
